# Propulsion

:warning: _This package is currently under development_

## Get Started

### Installing

The easiest way to install `propulsion` is via `pip`:

```console
pip install propulsion
```

<!-- TODO: Add optional install for click and other CLIs -->

### Simple Example

## How-to-Guides

## Deep Dive

### Contributing

1. Clone this repository `git clone git@github.com:alwinw/propulsion.git`
2. Install the development version `pip install -v -e .[<extras>]` (`-e` needs pip >= 22.0 for pyproject.toml) or `poetry install --extras "<extras>"`
3. Make your changes and commit using [commitizen](https://commitizen-tools.github.io/commitizen/#installation) and ensure [pre-commit](https://pre-commit.com/#install) is active
4. When ready, bump the version and run `poetry build -v`. If deploying, run `poetry publish --build -v`

## Acknowledgements

This package is heavily inspired by [Gooey](https://github.com/chriskiehl/Gooey) and [Rich CLI](https://github.com/Textualize/rich-cli). It would not be possible without [Textualize](https://github.com/Textualize) and [click](https://github.com/pallets/click)
